@@ -1,4 +1,5 @@
-import Queue, tg
+import Queue, tg, uuid
+from progress import asyncjobs_progress_status
 
 class AsyncJobQueue(object):
     def __init__(self):
@@ -8,20 +9,18 @@ class AsyncJobQueue(object):
     def get(self):
         return self.queue.get()
 
-    def done(self):
+    def done(self, entryid):
+        asyncjobs_progress_status.remove(entryid)
         self.queue.task_done()
 
     def perform(self, what, args, params):
+        uid = str(uuid.uuid1())
+        asyncjobs_progress_status.track(uid)
         self.queue.put({'callable':what,
                         'args':args,
-                        'params':params})
-
-def asyncjob_get():
-    return tg.app_globals.asyncjob_queue.get()
-
-def asyncjob_done():
-    tg.app_globals.asyncjob_queue.done()
+                        'params':params,
+                        'uid':uid})
+        return uid
 
 def asyncjob_perform(what, *args, **params):
-    tg.app_globals.asyncjob_queue.perform(what, args, params)
-    
+    return tg.app_globals.asyncjob_queue.perform(what, args, params)
