@@ -1,9 +1,10 @@
-import threading, transaction, logging, inspect
+import threading, transaction, logging
 from tg import config, app_globals
-from queue import AsyncJobQueue
 
 log = logging.getLogger('tgext.asyncjob')
 
+running_status = threading.local()
+
 class AsyncWorkerThread(threading.Thread):
     def __init__(self, queue):
         super(AsyncWorkerThread, self).__init__()
@@ -18,29 +19,28 @@ class AsyncWorkerThread(threading.Thread):
             func = msg.get('callable')
             args = msg.get('args')
             params = msg.get('params')
+            uid = msg.get('uid')
 
-            if func and args is not None and params is not None:
+            if not args:
+                args = []
+
+            if not params:
+                params = {}
+
+            if func:
                 transaction.begin()
                 try:
+                    running_status.entry = uid
                     func(*args, **params)
                     transaction.commit()
                 except Exception, e:
-                    log.exception('Exception in async job')
+                    log.exception('Exception in async job %s', uid)
                     transaction.abort()
 
-            self.queue.done()
+            running_status.entry = None
+            self.queue.done(uid)
             config.DBSession.remove()
 
-def start_async_worker(app_globals=None):
-    if not app_globals:
-        try:
-            app_globals = inspect.currentframe().f_back.f_locals['self']
-            log.info('App globals autodetected: %s', app_globals)
-        except:
-            log.error('Failed app globals autodetection, explicitly pass it to start_async_worker')
-            return
-
-    app_globals.asyncjob_queue = AsyncJobQueue()
-    worker = AsyncWorkerThread(app_globals.asyncjob_queue)
-    worker.start()
+def asyncjob_running_uid():
+    return running_status.entry
     
